#ifndef _GTKSOURCEVIEWMM_H
#define _GTKSOURCEVIEWMM_H

/* sourceviewmm.h
 * 
 * Based on gtksourceviewmm by Jae Jang
 * Copyright (C) 2005 Rob Page
 * 
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <gtksourceviewmm/init.h>
#include <gtksourceviewmm/sourcebuffer.h>
#include <gtksourceviewmm/sourceiter.h>
#include <gtksourceviewmm/sourcelanguage.h>
#include <gtksourceviewmm/sourcelanguagemanager.h>
#include <gtksourceviewmm/sourcemarker.h>
#include <gtksourceviewmm/sourcestylescheme.h>
#include <gtksourceviewmm/sourceview.h>

#endif /* #ifndef _GTKSOURCEVIEWMM_H */

